/* capilayer.h
 *
 * $Id: capilayer.h,v 1.11 2005/02/09 01:24:28 ianmacd Exp $
 *
 * Author: Ian Macdonald <ian@caliban.org>
 *
 * Copyright (C) 2004-2005 Ian Macdonald
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2, or (at your option)
 *   any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software Foundation,
 *   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#if defined(HAVE_CSDK_CONNECT)
#define HAVE_CAPI_90		/* Using version 9.0 of CAPI API */

#elif defined(HAVE_CAPI_AUTHENTICATEASSYSOP)
#define HAVE_CAPI_25		/* we're using version 2.5 or later of
				   CAPI API */
#else
#define HAVE_CAPI_20		/* we're using version 2.0 of CAPI API */
#endif

#define RBCTIME_MODIFY          (1)
#define RBCTIME_REPLACE         (1 << 1)
#define RBCTIME_REPLY           (1 << 2)

/* for debugging */
#define rb_ctime_debug(...) if (ruby_debug == Qtrue) { \
			       fprintf(stderr, __VA_ARGS__); \
			     }

extern CAPIStatus capi_connect (const char *in_host,
				const char *in_user,
				const char *in_password,
				CAPISession * out_session);

extern void capi_get_status_string (CAPIStatus status,
				    const char **out_string);

extern CAPIStatus capi_get_capabilities (CAPISession in_session,
					 CAPICapabilityID in_capabilityID,
					 const char **out_value);

extern CAPIStatus capi_destroy_multiple_handles (CAPISession in_session,
						 CAPIHandle * in_handle,
						 int num_handles);

extern CAPIStatus capi_disconnect (CAPISession * in_session);


extern CAPIStatus capi_get_handle (CAPISession in_session,
				   const char *in_user,
				   CAPIHandle * out_handle);

extern CAPIStatus capi_get_handle_info (CAPISession in_session,
					CAPIHandle in_handle,
					CAPIFlag in_flags,
					const char **out_info);

extern CAPIStatus capi_create_memory_stream (CAPISession in_session,
					     CAPIStream * out_stream,
					     const char *in_buffer,
					     const char **out_buffer);

extern CAPIStatus capi_destroy_stream (CAPISession in_session,
				       CAPIStream * in_stream);

extern CAPIStatus capi_fetch_event_by_uid (CAPISession in_session,
					   CAPIHandle in_handle,
					   const char *in_uid,
					   const char **in_req_properties,
					   int num_properties,
					   CAPIStream in_stream);

extern CAPIStatus capi_fetch_events_by_range (CAPISession in_session,
					      CAPIHandle * in_handles,
					      int num_handles,
					      const char *in_start,
					      const char *in_end,
					      const char **in_req_properties,
					      int num_properties,
					      CAPIStream in_stream);

extern CAPIStatus capi_set_identity (CAPISession in_session,
				     const char *in_user);

extern CAPIStatus capi_store_event (CAPISession session,
				    CAPIHandle * in_handles,
				    int num_handles,
				    CAPIStream in_stream,
				    char *uid_buf, int uid_buflen,
				    int updating);

extern CAPIStatus capi_delete_event (CAPISession in_session,
				     CAPIHandle * in_handles,
				     int num_handles, const char *uid);
